@@ -5,6 +5,12 @@
 ## Description: This file includes all global variables not related to the records
 ###########################################################################
 
+
+UsePySide = True #Switch between PySide and PyQt
+
+lc="en_US"
+encoding="UTF8"
+
 configFolder="/home/user/.SleepAnalyser/" #users home dir with ending /
 homedir="/home/user/"
 defaultRecordFolder="/home/user/MyDocs/SleepAnalyser/" #users record dir with ending /
