@@ -41,7 +41,7 @@ def CreateRecordFile():
     else: data.RecordFolder=data.defaultRecordFolder
 
     print "RecordFolder:", data.RecordFolder
-    if(not os.path.exists(str(data.RecordFolder))): #create record folder
+    if(not os.path.exists(data.RecordFolder)): #create record folder
         try:
             os.mkdir(data.RecordFolder)
         except: #can not create folder
@@ -81,7 +81,7 @@ def CreateRecordFile():
 ## Returns:     none
 ###########################################################################
 def CreateHeader():
-    if(records.SWversion<1.8): records.SWversion=1.8 #Workaround for missing version variable, update file version as header gets saved in new version
+    if(records.SWversion<1.8): records.SWversion=2.2 #Workaround for missing version variable, update file version as header gets saved in new version
 
     h=" , , , User: " + str(records.User.encode( "utf-8" ))+ \
         ", SW version: " + str(records.SWversion)+ \
@@ -101,7 +101,7 @@ def CreateHeader():
         h=h+"\n"+"Alarm Time Window End: "+strftime(data.dateformat,records.AlarmTimeWindowEnd_tuple)
         h=h+"\n"+"Use alternative Alarm: "+str(data.UseAlternativeAlarm)
         if(data.UseAlternativeAlarm==True):
-            h=h+"\n"+"Alternative Alarm: "+str(data.AlternativeAlarm)
+            h=h+"\n"+"Alternative Alarm: "+str(data.AlternativeAlarm.encode( "utf-8" ))
         else:
             h=h+"\n"+"Alternative Alarm: "
 
@@ -120,7 +120,12 @@ def CreateHeader():
             h=h+"\n"+ "Lucid dream song start: "+strftime(data.dateformat, records.Lucid_Dream_Song_Start_tuple)
         else:
             h=h+"\n"+ "Lucid dream song start: never"
-        h=h+"\n"+ "Lucid dream song: "+str(records.Lucid_Dream_Song)
+#        h=h+"\n"+ "Lucid dream song: "+str(records.Lucid_Dream_Song.encode( "utf-8" ))
+        try:
+            f=str(records.Lucid_Dream_Song.encode( "utf-8" ))
+        except:
+            f=str(records.Lucid_Dream_Song)
+        h=h+"\n"+ "Lucid dream song: "+f
         h=h+"\n"+ "Lucid dream song delay: "+str(records.Lucid_Dream_Song_Delay)
         h=h+"\n"+ "Lucid dream song duration: "+str(records.Lucid_Dream_Song_Duration)
         h=h+"\n"+ "Lucid dream song volume: "+str(records.Lucid_Dream_Song_Volume)
@@ -137,7 +142,12 @@ def CreateHeader():
             h=h+"\n"+ "WakeUp song start: "+strftime(data.dateformat, records.WakeUp_Song_Start_tuple)
         else:
             h=h+"\n"+ "WakeUp song start: never"
-        h=h+"\n"+ "WakeUp song: "+str(records.WakeUp_Song)
+#        h=h+"\n"+ "WakeUp song: "+str(records.WakeUp_Song.encode( "utf-8" ))
+        try:
+            f=str(records.WakeUp_Song.encode( "utf-8" ))
+        except:
+            f=str(records.WakeUp_Song)
+        h=h+"\n"+ "WakeUp song: "+f
         h=h+"\n"+ "WakeUp song duration: "+str(records.WakeUp_Song_Duration)
         h=h+"\n"+ "WakeUp song volume: "+str(records.WakeUp_Song_Volume)
     else:
@@ -241,13 +251,20 @@ def LoadFileList():
 def LoadRecord():
     InitRecord() #clear all old data
 
-    data.RecordFolder=string.replace(data.RecordFolder, "~", data.homedir) #workaround
-    print "Open recordfile:", data.RecordFolder+data.RecordFilename, "to load data..."
-    if(not os.path.exists(str(data.RecordFolder))): #create record folder (dirty workaround for if folder is not existing
+
+    data.RecordFolder=string.replace(data.RecordFolder, u"~", data.homedir) #workaround
+    print "Open recordfile:", data.RecordFilename, "in", data.RecordFolder,  "to load data..."
+    if(not os.path.exists(data.RecordFolder)): #create record folder (dirty workaround for if folder is not existing
         os.mkdir(data.RecordFolder)
         data.LastRecord=""
+
+    try:
+        data.RecordFilename = data.RecordFilename.decode("utf-8")
+    except:
+        pass   
+        
     f=data.RecordFolder+data.RecordFilename
-    if(not os.path.exists(str(f)) or data.RecordFilename==""): return 2 #selected file or folder does not exist
+    if(not os.path.exists(f) or data.RecordFilename==""): return 2 #selected file or folder does not exist
 
     file = open(f, 'r')
 
