@@ -5,9 +5,18 @@
 ## Description: This file includes various functions
 ###########################################################################
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
-from PyQt4 import QtCore, QtGui
+
+
+import data
+
+if(data.UsePySide == True):
+    from PySide.QtCore import *
+    from PySide.QtGui import *
+    from PySide import QtCore, QtGui    
+else:    
+    from PyQt4.QtCore import *
+    from PyQt4.QtGui import *
+    from PyQt4 import QtCore, QtGui
 
 import sys
 import os
@@ -22,7 +31,7 @@ import ConfigParser
 import os, os.path
 
 import dbus
-from dbus.mainloop.qt import DBusQtMainLoop
+#from dbus.mainloop.qt import DBusQtMainLoop
 
 #import shlex, subprocess
 
@@ -35,7 +44,6 @@ from dbus.mainloop.qt import DBusQtMainLoop
 #import gst
 
 
-import data
 import filter_data #filter
 import records #record data
 
@@ -93,7 +101,7 @@ def WritePresetNames():
 
     f=data.configFolder+data.PresetNamesFile
     if(data.debug==True): print "Save preset names ("+f+")"
-    if (not os.path.exists(str(data.configFolder))):
+    if (not os.path.exists(data.configFolder)):
         print "Create configuration folder: ", data.configFolder
         os.mkdir(data.configFolder)
 #    try:
@@ -168,10 +176,16 @@ def LoadConfig():
 
     data.LastRecord = Config_Load_String('main', 'LastRecord', data.LastRecord)
     data.AlternativeAlarm = Config_Load_String('main', 'AlternativeAlarm', data.AlternativeAlarm)
+    data.AlternativeAlarm = data.AlternativeAlarm.decode("utf-8")
+    
     data.Lucid_Dream_Song = Config_Load_String('main', 'Lucid_Dream_Song', data.Lucid_Dream_Song)
+    data.Lucid_Dream_Song = data.Lucid_Dream_Song.decode("utf-8")
     data.WakeUp_Song = Config_Load_String('main', 'WakeUp_Song', data.WakeUp_Song)
+    data.WakeUp_Song = data.WakeUp_Song.decode("utf-8")
     data.cliStart = Config_Load_String('main', 'cliStart', data.cliStart)
+#    data.cliStart = data.cliStart.decode("utf-8") ##has to be solved differently!
     data.cliStop = Config_Load_String('main', 'cliStop', data.cliStop)
+#    data.cliStart = data.cliStart.decode("utf-8")  ##has to be solved differently!
 
 
     data.OfflineMode = Config_Load_Bool('main', 'OfflineMode', data.OfflineMode)
@@ -275,7 +289,7 @@ def WriteConfig():
 
     f=data.configFolder+data.ConfigFile
     if(data.debug==True): print "Save configuration ("+f+")"
-    if (not os.path.exists(str(data.configFolder))):
+    if (not os.path.exists(data.configFolder)):
         print "Create configuration folder: ", data.configFolder
         try:
             os.mkdir(data.configFolder)
@@ -551,7 +565,13 @@ def Notify(notify_txt):
 ## Returns:     array with files
 ###########################################################################
 def getFileList(path,  filter):
-    output = os.popen("cd \""+str(path)+"\"; ls -C1 "+str(filter)).read() # run ls and make the output look like a file I can read
+    try:
+        path = path.encode("utf-8")
+    except:
+        pass
+        
+    cmd = "cd \""+path+"\"; ls -C1 "+str(filter)
+    output = os.popen(cmd).read() # run ls and make the output look like a file I can read
     #Note: Above command could also be implemented with os.listdir(). This might give a minor speed improvement
     arr=output.split("\n")
     arr.pop()
@@ -579,9 +599,18 @@ def getFileList(path,  filter):
 ## Parameters:  path to song file
 ## Returns:     song duration in seconds
 ###########################################################################
-def GetSongLength(filename):
-    print "get song length for file:", filename
-    output = os.popen("ffmpeg -i \""+str(filename)+"\" 2>&1 | grep Duration").read() # run ffmpeg and make the output look like a file I can read
+def GetSongLength(filename):    
+    try:
+        filename = filename.encode("utf-8")
+    except:
+        pass
+    try:
+        print "get song length for file:", filename
+    except:
+        pass
+    cmd = "ffmpeg -i \""+ filename +"\" 2>&1 | grep Duration"    
+    output = os.popen(cmd).read() # run ffmpeg and make the output look like a file I can read
+#    print output
     arr=output.split(".")
     arr=arr[0].split(":")
 
@@ -592,4 +621,5 @@ def GetSongLength(filename):
         duration=300 #set to 5 minutes
         print "ERROR: Could not get song length!"
         print "Set to default 5 minutes"
+#    print duration
     return duration
